@@ -1,8 +1,8 @@
 
 import copy
 import json
-from openapi_schema_to_json_schema import to_json_schema
 import jsonschema
+from .converter import to_json_schema
 
 try:
     from django.db.models import JSONField
