@@ -3,7 +3,7 @@ import copy
 from jsonschema_to_openapi.convert import convert as convert_to_openapi
 from rest_framework import serializers
 from rest_framework.exceptions import ValidationError
-from openapi_schema_to_json_schema import to_json_schema
+from .converter import to_json_schema
 
 from .fields import ValidatedJSONField as ModelValidatedJSONField
 from .fields import ExtendedJsonValidatorWithDefault
@@ -15,7 +15,7 @@ class ValidatedJSONField(serializers.JSONField):
             self.coreapi_schema = convert_to_openapi(copy.deepcopy(self.schema) )
         self.json_validator_cls = kwargs.pop("json_validator_cls", None)
         if(self.json_validator_cls is None and self.schema is not None):
-            jsschema = to_json_schema(schema, {"supportPatternProperties": True})            
+            jsschema = to_json_schema(self.schema, {"supportPatternProperties": True})            
             self.json_validator_cls = ExtendedJsonValidatorWithDefault(jsschema)
 
         #MIXING validators among multiple ModelValidatedJSONField, we should try not to use the validators argument
